import { SpecType, Model } from 'pretur.spec';
import { Query } from './query';
import { SelectResult, OperateResult, InsertMutateResult, UpdateMutateResult, RemoveMutateResult, ValidateResult } from './result';
export declare type InsertOptions<T extends SpecType> = {
    data: Partial<Model<T>>;
    model: T['name'];
};
export declare type UpdateOptions<T extends SpecType> = {
    data: Partial<T['fields']>;
    attributes: (keyof T['fields'])[];
    model: T['name'];
};
export declare type RemoveOptions<T extends SpecType> = {
    identifiers: Partial<T['fields']>;
    model: T['name'];
};
export interface Requester {
    select<T extends SpecType>(query: Query<T>): Promise<SelectResult<T>>;
    operate<TData, TResult>(name: string, data?: TData): Promise<OperateResult<TResult>>;
    insert<T extends SpecType>(options: InsertOptions<T>): Promise<InsertMutateResult<T>>;
    insert<T extends SpecType>(model: T['name'], data: Partial<Model<T>>): Promise<InsertMutateResult<T>>;
    update<T extends SpecType>(options: UpdateOptions<T>): Promise<UpdateMutateResult>;
    update<T extends SpecType>(model: T['name'], attributes: (keyof T['fields'])[], data: Partial<T['fields']>): Promise<UpdateMutateResult>;
    remove<T extends SpecType>(options: RemoveOptions<T>): Promise<RemoveMutateResult>;
    remove<T extends SpecType>(model: T['name'], identifiers: Partial<T['fields']>): Promise<RemoveMutateResult>;
    validate<T>(name: string, data: T): Promise<ValidateResult>;
    batchMutateStart(): void;
    batchMutateEnd(): void;
    flush(): void;
    cancel(): void;
}
export declare function buildRequester(endPoint: string, wait?: number, maxWait?: number): Requester;
